﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class PlayerMovement : MonoBehaviour
{
    public float currentSpeed;
    public float walkSpeed;
    public float sprintMultiplier;
    public bool isSprinting;

    private PlayerStats playerStats;

    public Rigidbody2D rb;

    private Vector2 movement;

    private Vector2 look;

    private void Start()
    {
        currentSpeed = walkSpeed;
        //sprintMultiplier;    //some reason not updating in editor even tho its value is assigned in instantiation
        playerStats = GameObject.FindGameObjectWithTag("Player").GetComponent<PlayerStats>();
    }

    // still use this to register input, but dont act on it
    void Update()
    { 
        movement.x = Input.GetAxisRaw("Horizontal");
        movement.y = Input.GetAxisRaw("Vertical");

        if (Input.GetKey(KeyCode.LeftShift))
        {
            Debug.Log("SPRINT PRESSED");
            if (playerStats.GetCurStamina() > 0)
            {
                isSprinting = true;
            } else
            {
                isSprinting = false;
            }
        } else
        {
            isSprinting = false;
        }
    }

    // act on input
    private void FixedUpdate()
    {
        Sprint();
        RegenStamina();
        LookAtMouse();  //here and not in Update to help with jittering
        rb.MovePosition(rb.position + movement * currentSpeed * Time.fixedDeltaTime);
    }

    void LookAtMouse()
    {
        var direction = Input.mousePosition - Camera.main.WorldToScreenPoint(transform.position);
        var angle = Mathf.Atan2(direction.y, direction.x) * Mathf.Rad2Deg;
        transform.rotation = Quaternion.AngleAxis(angle, Vector3.forward);
    }

    void Sprint()
    {
        switch (isSprinting)
        {
            case true:
                Debug.Log("ur sprinting");
                currentSpeed = walkSpeed * sprintMultiplier;
                playerStats.DecreaseStamina();
                break;
            case false:
                currentSpeed = walkSpeed;
                Debug.Log("not currently sprinting");
                break;
        }
    }

    void RegenStamina()
    {
        if (!isSprinting)
        {
            playerStats.IncreaseStamina();
            if (playerStats.GetCurStamina() > playerStats.GetMaxStamina())
            {
                playerStats.currentStamina = playerStats.maxStamina;
            }
        }
    }
}
