﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.Experimental.Rendering.LWRP;
using UnityEngine.SceneManagement;

public class PlayerStats : MonoBehaviour
{
    public int ammo = 5;
    public int maxHealth = 100;
    public int currentHealth;
    public int wood, stone, scrap, key = 0;

    public bool lightOn;
    public int maxPower = 1500;  //just going with stamina drain rate, since UI elements are prefab variants
    public int currentPower;

    public int maxStamina = 600; //not 100 because of rate of drain I want, didnt feel like using a float since all other stats are int
    public int currentStamina;

    public GameObject alivePanel;
    public GameObject deadPanel;

    private GameObject headLamp;
    public UnityEngine.Experimental.Rendering.LWRP.Light2D lamp;
    [SerializeField] float originalIntensity;
    [SerializeField] float currentIntensity; //literally just for testing

    private void Start()
    {
        currentHealth = maxHealth;
        currentStamina = maxStamina;
        currentPower = maxPower;
        lightOn = false;
        headLamp = GameObject.FindGameObjectWithTag("HeadLamp");
        headLamp.SetActive(false);

        originalIntensity = lamp.intensity;
        currentIntensity = originalIntensity;
    }

    void Update()
    {
        if (currentHealth <= 0)
        {
            Destroy(gameObject, 3.5f);
            alivePanel.SetActive(false);
            deadPanel.SetActive(true);

            StartCoroutine("MainMenu");
        } else
        {
            Headlamp();
            TurnOffLight();
            RegenPower();
        }
    }

    IEnumerator MainMenu()
    {
        yield return new WaitForSeconds(3f);
        SceneManager.LoadScene(0);
    }

    private void FixedUpdate()
    {
        DrainPower();   //using fixed update to get consistent drain rate
        ReduceLight();
    }

    //drains battery 50 times a second for as long as light is on
    void DrainPower()
    {
        if (lightOn && currentPower > 0)
        {
            DecreasePower();
        }
    }

    //turn off light automatically once ur out of power
    void TurnOffLight()
    {
        if (currentPower == 0)
        {
            headLamp.SetActive(false);
            lightOn = false;
        }
    }

    //lowers intensity gradually based on battery percentage
    void ReduceLight()
    {
        if (lightOn && currentPower < maxPower / 2)
        {
            lamp.intensity -= 0.0004f;
            currentIntensity = lamp.intensity; //for testing
        }
    }

    //there is a much more concise way to do this by scrapping Power altogether, but short on time
    //could just adjust intensity directly w/o having some middle-man value
    void RegenPower()
    {
        if (!lightOn)
        {
            if (currentPower < maxPower)
            {
                IncreasePower();
                if (currentPower < maxPower / 2 && lamp.intensity <= originalIntensity)
                {
                    lamp.intensity += 0.0004f;
                    currentIntensity = lamp.intensity; //more testing
                }
            } else
            {
                currentPower = maxPower;
            }
            //wasnt being reach soon enough in original spot, intensity always ended up at 5.005 instead of 5
            if (lamp.intensity > originalIntensity)
            {
                lamp.intensity = originalIntensity;
            }

            //safe measure just in case code above fails (sometimes off by.0004 at half power)
            if (currentPower > maxPower)
            {
                lamp.intensity = originalIntensity;
            }
        }
    }

    void Headlamp()
    {
        if (Input.GetKeyDown(KeyCode.F))
        {
            switch (lightOn)
            {
                case true:
                    headLamp.SetActive(false);
                    lightOn = false;
                    break;
                case false:
                    headLamp.SetActive(true);
                    lightOn = true;
                    break;
            }
        }
    }

    public int GetAmmo()
    {
        return ammo;
    }

    public void IncreaseAmmo()
    {
        ammo++;
    }

    public void IncreaseAmmo(int amount)
    {
        ammo += amount;
    }

    public void DecreaseAmmo()
    {
        ammo--;
    }

    public int GetMaxHP()
    {
        return maxHealth;
    }

    public int GetCurHP()
    {
        return currentHealth;
    }

    public int GetMaxStamina()
    {
        return maxStamina;
    }

    public void SetHP(int amount)
    {
        currentHealth += amount;
        if (currentHealth > maxHealth)
        {
            currentHealth = maxHealth;
        }
    }

    public int GetCurStamina()
    {
        return currentStamina;
    }

    public void IncreaseStamina()
    {
        currentStamina++;
    }

    public void DecreaseStamina()
    {
        currentStamina -= 2;
    }

    public void IncreasePower()
    {
        currentPower++;
    }

    public void DecreasePower()
    {
        if (currentPower > 0)
        {
            currentPower--; //power drains half as fast as stamina
        } else
        {
            currentPower = 0;
        }
    }

    public void PlayerTakeDmg(int dmg)
    {
        currentHealth -= dmg;
    }

    public void PlayerGainHP(int hp)
    {
        currentHealth += hp;
        if (currentHealth > maxHealth)
        {
            currentHealth = maxHealth;
        }
    }

    public int GetWood()
    {
        return wood;
    }

    public void SetWood(int amount)
    {
        wood += amount;
    }

    public int GetStone()
    {
        return stone;
    }

    public void SetStone(int amount)
    {
        stone += amount;
    }

    public int GetScrap()
    {
        return scrap;
    }

    public void SetScrap(int amount)
    {
        scrap += amount;
    }

    public int GetKey()
    {
        return key;
    }

    public void SetKey(int amount)
    {
        key += amount;
    }
}
